/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package kubernetes

import "strings"

// IsUnknownAPIError checks if the given error is due to some missing APIs in the cluster.
// Apparently there's no such method in Kubernetes Go API.
func IsUnknownAPIError(err error) bool {
	return err != nil && (strings.HasPrefix(err.Error(), "no matches for kind") || strings.HasPrefix(err.Error(), "failed to get API group resources"))
}
